netapp_ontap.resources.s3_group API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.s3_group`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

An S3 group consists of one or many users. Policies are attached to the S3 group to have access control over S3 resources at group level.

## Examples

### Retrieving all fields for all S3 groups of an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Group

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                S3Group.get_collection(
                    "12f3ba4c-7ae0-11e9-8c06-0050568ea123", fields="*", return_timeout=15
                )
            )
        )

Try it out

    [
        S3Group(
            {
                "svm": {"uuid": "02c9e252-41be-11e9-81d5-00a0986138f7", "name": "svm1"},
                "users": [{"name": "User1"}, {"name": "User2"}, {"name": "User3"}],
                "id": 5,
                "policies": [{"name": "Policy1"}, {"name": "Policy2"}, {"name": "Policy3"}],
                "name": "Admin-Group",
                "comment": "Admin group",
            }
        ),
        S3Group(
            {
                "svm": {"uuid": "02c9e252-41be-11e9-81d5-00a0986138f7", "name": "svm1"},
                "users": [{"name": "User1"}, {"name": "User2"}, {"name": "User6"}],
                "id": 6,
                "policies": [{"name": "Policy1"}, {"name": "Policy2"}, {"name": "Policy3"}],
                "name": "Admin-Group1",
                "comment": "Admin group",
            }
        ),
    ]

### Retrieving the specified group in the SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Group

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Group("12f3ba4c-7ae0-11e9-8c06-0050568ea123", id=5)
        resource.get(fields="*")
        print(resource)

Try it out

    S3Group(
        {
            "svm": {"uuid": "02c9e252-41be-11e9-81d5-00a0986138f7", "name": "svm1"},
            "users": [{"name": "User1"}, {"name": "User2"}, {"name": "User3"}],
            "id": 5,
            "policies": [{"name": "Policy1"}, {"name": "Policy2"}, {"name": "Policy3"}],
            "name": "Admin-Group",
            "comment": "Admin group",
        }
    )

### Creating an S3 group for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Group

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Group("12f3ba4c-7ae0-11e9-8c06-0050568ea123")
        resource.comment = "Admin group"
        resource.name = "Admin-Group"
        resource.policies = [{"name": "Policy1"}, {"name": "Policy2"}, {"name": "Policy3"}]
        resource.users = [{"name": "User1"}, {"name": "User2"}, {"name": "User3"}]
        resource.post(hydrate=True)
        print(resource)

Try it out

    S3Group(
        {
            "svm": {"uuid": "02c9e252-41be-11e9-81d5-00a0986138f7", "name": "svm1"},
            "users": [{"name": "User1"}, {"name": "User2"}, {"name": "User3"}],
            "id": 5,
            "policies": [{"name": "Policy1"}, {"name": "Policy2"}, {"name": "Policy3"}],
            "name": "Admin-Group",
            "comment": "Admin group",
        }
    )

### Updating an S3 group for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Group

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Group("12f3ba4c-7ae0-11e9-8c06-0050568ea123", id=5)
        resource.comment = "Admin group"
        resource.name = "Admin-Group"
        resource.policies = [{"name": "Policy1"}]
        resource.users = [{"name": "user-1"}]
        resource.patch()

### Deleting an S3 group for a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import S3Group

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = S3Group("12f3ba4c-7ae0-11e9-8c06-0050568ea123", id=5)
        resource.delete()

## Classes

`class S3Group (*args, **kwargs)`

  This is a container for S3 user groups.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the S3 group's SVM configuration.

    ### Related ONTAP commands

    - `vserver object-store-server group show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the S3 group configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server group delete`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the S3 group's SVM configuration.

    ### Related ONTAP commands

    - `vserver object-store-server group show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the S3 group's SVM configuration.

    ### Related ONTAP commands

    - `vserver object-store-server group show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the S3 group configuration of an SVM.

    ### Important notes

    - The following fields can be modified for a group:
    - `name` - Group name that needs to be modified.
    - `users` - List of users present in the group.
    - `policies` - List of policies to be attached to this group.

    ### Recommended optional properties

    - `comment` - Short description about the S3 Group.

    ### Related ONTAP commands

    - `vserver object-store-server group modify`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the S3 group configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server group delete`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the S3 group configuration of an SVM.

    ### Related ONTAP commands

    - `vserver object-store-server group show`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the S3 group configuration of an SVM.

    ### Important notes

    - The following fields can be modified for a group:
    - `name` - Group name that needs to be modified.
    - `users` - List of users present in the group.
    - `policies` - List of policies to be attached to this group.

    ### Recommended optional properties

    - `comment` - Short description about the S3 Group.

    ### Related ONTAP commands

    - `vserver object-store-server group modify`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates the S3 group configuration.

    ### Important notes

    - Each SVM can have one or more s3 group configurations.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create the user configuration.
    - `name` - Group name that is to be created.
    - `users` - List of users to be added into the group.
    - `policies` - List of policies are to be attached to this group.

    ### Recommended optional properties

    - `comment` - Short description about the S3 Group.

    ### Related ONTAP commands

    - `vserver object-store-server group create`

    ### Learn more

    - `DOC /protocols/s3/services/{svm.uuid}/groups`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class S3GroupSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the S3Group object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `comment GET POST PATCH`

    Can contain any additional information about the group being created or modified.

    Example: Admin group

  `id GET`

    Specifies a unique group ID used to identify a particular group. This parameter should not be specified in the POST method. A group ID is automatically generated and it is retrieved using the GET method. Group id is SVM scoped.

    Example: 5

  `name GET POST PATCH`

    Specifies the name of the group. A group name length can range from 1 to 128 characters and can only contain the following combination of characters 0-9, A-Z, a-z, "_", "+", "=", ",", ".","@", and "-".

    Example: Admin-Group

  `policies GET POST PATCH`

    Specifies a list of policies that are attached to the group. The wildcard character "*" is a valid value for specifying all policies.

  `svm GET POST PATCH`

    The svm field of the s3_group.

  `users GET POST PATCH`

    Specifies the list of users who belong to the group.